@@ -46,7 +46,7 @@ int32_t SPVM__Regex__compile(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_re2 = env->new_pointer_by_name(env, stack, "Regex::Re2", re2.release(), &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
-  env->set_field_object_by_name(env, stack, obj_self, "Regex", "re2", "Regex::Re2", obj_re2, &e, FILE_NAME, __LINE__);
+  env->set_field_object_by_name_v2(env, stack, obj_self, "Regex", "re2", obj_re2, &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   return 0;
@@ -79,7 +79,7 @@ int32_t SPVM__Regex__match_offset(SPVM_ENV* env, SPVM_VALUE* stack) {
     return 0;
   }
   
-  void* obj_re2 = env->get_field_object_by_name(env, stack, obj_self, "Regex", "re2", "Regex::Re2", &e, FILE_NAME, __LINE__);
+  void* obj_re2 = env->get_field_object_by_name_v2(env, stack, obj_self, "Regex", "re2", &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (!obj_re2) {
@@ -119,7 +119,7 @@ int32_t SPVM__Regex__match_offset(SPVM_ENV* env, SPVM_VALUE* stack) {
           env->set_elem_object(env, stack, obj_captures, i, obj_capture);
         }
       }
-      env->set_field_object_by_name(env, stack, obj_self, "Regex", "captures", "string[]", obj_captures, &e, FILE_NAME, __LINE__);
+      env->set_field_object_by_name_v2(env, stack, obj_self, "Regex", "captures", obj_captures, &e, FILE_NAME, __LINE__);
       if (e) { return e; }
     }
     
@@ -141,7 +141,7 @@ int32_t SPVM__Regex__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_self = stack[0].oval;
 
-  void* obj_re2 = env->get_field_object_by_name(env, stack, obj_self, "Regex", "re2", "Regex::Re2", &e, FILE_NAME, __LINE__);
+  void* obj_re2 = env->get_field_object_by_name_v2(env, stack, obj_self, "Regex", "re2", &e, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   if (obj_re2) {
